# LearnRL a python library to learn and use reinforcement learning
# Copyright (C) 2020 Mathïs FEDERICO <https://www.gnu.org/licenses/>

from learnrl.agents.standard import StandardAgent
from learnrl.agents.random import RandomAgent
